@@ -4,11 +4,11 @@
 # various utility functions
 
 package Music::RhythmSet;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use 5.24.0;
 use warnings;
-use Carp qw(croak);
+use Carp                        qw(croak);
 use List::GroupingPriorityQueue qw(grpriq_add);
 use MIDI;
 use Moo;
@@ -20,8 +20,7 @@ has stash  => ( is => 'rw' );
 has voices => ( is => 'rw', default => sub { [] } );
 
 # perldoc Moo
-sub BUILD
-{
+sub BUILD {
     my ( $self, $args ) = @_;
     # so ->new->add(...) can instead be written ->new(voicel => [...])
     if ( exists $args->{voicel} ) {
@@ -37,8 +36,7 @@ sub BUILD
 #
 # METHODS
 
-sub add
-{
+sub add {
     my ( $self, @rest ) = @_;
     croak "nothing to add" unless @rest;
 
@@ -54,8 +52,7 @@ sub add
     return $self;
 }
 
-sub advance
-{
+sub advance {
     my ( $self, $count, %param ) = @_;
     # this is done stepwise for each voice so that TTL expirations and
     # thus potential new patterns are more likely to be visible to other
@@ -72,8 +69,7 @@ sub advance
     return $self;
 }
 
-sub changes
-{
+sub changes {
     my ( $self, %param ) = @_;
 
     for my $cb (qw{header voice}) {
@@ -135,8 +131,7 @@ sub changes
     return $self;
 }
 
-sub clone
-{
+sub clone {
     my ($self) = @_;
 
     my $new = Music::RhythmSet->new;
@@ -151,8 +146,7 @@ sub clone
     return $new;
 }
 
-sub from_string
-{
+sub from_string {
     my ( $self, $str, %param ) = @_;
     croak "need a string" unless defined $str and length $str;
 
@@ -209,8 +203,7 @@ sub from_string
     return $self;
 }
 
-sub measure
-{
+sub measure {
     my ( $self, $num ) = @_;
     for my $voice ( $self->voices->@* ) {
         $voice->measure($num);
@@ -218,8 +211,7 @@ sub measure
     return $self;
 }
 
-sub to_ly
-{
+sub to_ly {
     my ( $self, %param ) = @_;
 
     for my $id ( 0 .. $self->voices->$#* ) {
@@ -233,15 +225,16 @@ sub to_ly
     return [ map { $_->to_ly( $param{voice}->[ $id++ ]->%* ) } $self->voices->@* ];
 }
 
-sub to_midi
-{
+sub to_midi {
     my ( $self, %param ) = @_;
 
     $param{format} //= 1;
     $param{ticks}  //= 96;
 
     for my $id ( 0 .. $self->voices->$#* ) {
-        for my $pram (qw/chan dur embig maxm note notext tempo sustain velo/) {
+        for
+          my $pram (qw/chan dur embig maxm note notext tempo sustain velo patch_change/)
+        {
             $param{track}[$id]{$pram} = $param{$pram}
               if exists $param{$pram} and not exists $param{track}[$id]{$pram};
         }
@@ -257,8 +250,7 @@ sub to_midi
     );
 }
 
-sub to_string
-{
+sub to_string {
     my ( $self, @rest ) = @_;
 
     my $str = '';
