@@ -4,11 +4,11 @@
 # of beats, and etc
 
 package Music::RhythmSet::Util;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use 5.24.0;
 use warnings;
-use Carp qw(croak);
+use Carp             qw(croak);
 use Statistics::Lite qw(stddevp);
 
 use constant { NOTE_ON => 1, NOTE_OFF => 0 };
@@ -17,16 +17,14 @@ use parent qw(Exporter);
 our @EXPORT_OK =
   qw(beatstring compare_onsets duration filter_pattern flatten ocvec onset_count pattern_from rand_onsets score_fourfour score_stddev upsize write_midi);
 
-sub beatstring
-{
+sub beatstring {
     my ($bpat) = @_;
     croak "no pattern set"
       unless defined $bpat and ref $bpat eq 'ARRAY';
     return join( '', $bpat->@* ) =~ tr/10/x./r;
 }
 
-sub compare_onsets
-{
+sub compare_onsets {
     my ( $first, $second ) = @_;
 
     my $same   = 0;
@@ -43,8 +41,7 @@ sub compare_onsets
     return $same / $onsets;
 }
 
-sub duration
-{
+sub duration {
     my ($replay) = @_;
     croak "no replay log"
       unless defined $replay and ref $replay eq 'ARRAY';
@@ -60,8 +57,7 @@ sub duration
     return $measures, $beats;
 }
 
-sub filter_pattern
-{
+sub filter_pattern {
     my ( $onsets, $total, $trials, $fudge, $nozero ) = @_;
 
     $fudge //= 0.0039;
@@ -81,8 +77,7 @@ sub filter_pattern
     return $bpat;
 }
 
-sub flatten
-{
+sub flatten {
     my ($replay) = @_;
     croak "no replay log"
       unless defined $replay and ref $replay eq 'ARRAY';
@@ -90,8 +85,7 @@ sub flatten
 }
 
 # "onset-coordinate vector" notation for a pattern
-sub ocvec
-{
+sub ocvec {
     my ($bpat) = @_;
     croak "no pattern set"
       unless defined $bpat and ref $bpat eq 'ARRAY';
@@ -107,8 +101,7 @@ sub ocvec
     return \@set;
 }
 
-sub onset_count
-{
+sub onset_count {
     my ($bpat) = @_;
     croak "no pattern set"
       unless defined $bpat and ref $bpat eq 'ARRAY';
@@ -122,16 +115,14 @@ sub onset_count
     return $onsets;
 }
 
-sub pattern_from
-{
+sub pattern_from {
     my ($string) = @_;
     $string =~ tr/x.//cd;
     $string =~ tr/x./10/;
     return [ split '', $string ];
 }
 
-sub rand_onsets
-{
+sub rand_onsets {
     my ( $onsets, $total ) = @_;
     croak "onsets must be < total" if $onsets >= $total;
 
@@ -149,8 +140,7 @@ sub rand_onsets
     return \@pattern;
 }
 
-sub score_fourfour
-{
+sub score_fourfour {
     my ($bpat) = @_;
 
     my @beatquality = map { 256 - $_ } qw(
@@ -170,8 +160,7 @@ sub score_fourfour
     return $score;
 }
 
-sub score_stddev
-{
+sub score_stddev {
     my ($bpat) = @_;
 
     my @deltas;
@@ -195,8 +184,7 @@ sub score_stddev
     return stddevp(@deltas);
 }
 
-sub upsize
-{
+sub upsize {
     my ( $bpat, $newlen ) = @_;
     croak "no pattern set"
       unless defined $bpat
@@ -214,8 +202,7 @@ sub upsize
     return \@pat;
 }
 
-sub write_midi
-{
+sub write_midi {
     my ( $file, $track, %param ) = @_;
 
     $param{format} //= 1;
